@@ -144,14 +144,23 @@ class DataSource2D(QtCore.QObject):
                     self._counter_param = self.get_settings('counter_roi', int)
 
                     for ind in range(self.get_settings('num_rois', int)):
-                        self.rois.append({'x': self.get_settings('roi_{}_x'.format(ind), int),
-                                          'y': self.get_settings('roi_{}_y'.format(ind), int),
-                                          'w': self.get_settings('roi_{}_w'.format(ind), int),
-                                          'h': self.get_settings('roi_{}_h'.format(ind), int),
-                                          'bg': self.get_settings('roi_{}_bg'.format(ind), int),
-                                          'visible': self.get_settings('roi_{}_visible'.format(ind), bool),
-                                          'mark': self.get_settings('roi_{}_mark'.format(ind), str),
-                                          'color': self.get_settings('roi_{}_color'.format(ind), str)})
+                        params = {'bg': self.get_settings('roi_{}_bg'.format(ind), int),
+                                  'visible': self.get_settings('roi_{}_visible'.format(ind), bool),
+                                  'mark': self.get_settings('roi_{}_mark'.format(ind), str),
+                                  'color': self.get_settings('roi_{}_color'.format(ind), str)}
+
+                        if ind == self._counter_roi:
+                            params.update({'x': self.get_settings('counter_x', int),
+                                           'y': self.get_settings('counter_y', int),
+                                           'w': self.get_settings('counter_w', int),
+                                           'h': self.get_settings('counter_h', int)})
+                        else:
+                            params.update({'x': self.get_settings('roi_{}_x'.format(ind), int),
+                                           'y': self.get_settings('roi_{}_y'.format(ind), int),
+                                           'w': self.get_settings('roi_{}_w'.format(ind), int),
+                                           'h': self.get_settings('roi_{}_h'.format(ind), int)})
+
+                        self.rois.append(params)
 
                         if ind == self._counter_roi:
                             for setting in ['x', 'y', 'w', 'h']:
@@ -424,6 +433,10 @@ class DataSource2D(QtCore.QObject):
             for param in ['x', 'y', 'w', 'h', 'bg', 'visible', 'mark']:
                 self.save_settings('roi_{}_{}'.format(ind, param), roi[param])
 
+            if ind == self._counter_roi:
+                for setting in ['x', 'y', 'w', 'h']:
+                    self.save_settings('counter_{}'.format(setting), roi[setting])
+
     # ----------------------------------------------------------------------
     def set_roi_value(self, roi_id, setting, value):
         """
@@ -519,8 +532,11 @@ class DataSource2D(QtCore.QObject):
             if info['visible']:
 
                 image_size = self.get_picture_clip()
+                _reduction = self.get_reduction()
+
                 _image_x_pos, _image_y_pos = image_size[0], image_size[1]
-                x, y, w, h = int(info['x'] - _image_x_pos), int(info['y'] - _image_y_pos), int(info['w']), int(info['h'])
+                x, y, = int((info['x'] - _image_x_pos) // _reduction), int((info['y'] - _image_y_pos) // _reduction)
+                w, h = int(info['w'] // _reduction), int(info['h'] // _reduction)
 
                 array = self._last_frame[x:x + w, y:y + h]
                 if array != []:
