@@ -1,6 +1,8 @@
 # Created by matveyev at 22.02.2022
 
 from distutils.util import strtobool
+import PyTango
+import HasyUtils as hu
 
 from PyQt5 import QtWidgets, QtCore
 
@@ -19,16 +21,26 @@ class CameraSettings(QtWidgets.QWidget):
         self._ui = Ui_CameraSettings()
         self._ui.setupUi(self)
 
+        self._ui.fr_tango.setVisible(False)
+        self._ui.fr_vimba_picture_setings.setVisible(False)
+
         self.my_id = my_id
 
         self._ui.cmb_camera_type.currentTextChanged.connect(self._switch_camera_type)
         self._ui.cmb_motor_type.currentTextChanged.connect(self._switch_motor_type)
 
+        self._ui.cmb_camera_type.addItems(['LMScreen', 'TangoVimba'])
+        self._ui.cmb_motor_type.addItems(['None', 'FSBT', 'Acromag'])
+
+        self._ui.le_tango_host.setText(PyTango.Database().get_db_host().split('.')[0])
+        self._rescan_database()
+
         self._ui.cmd_delete.clicked.connect(lambda status, x=my_id: self.delete_me.emit(x))
         self._ui.le_name.editingFinished.connect(self._new_name)
 
-        self._ui.cmb_camera_type.addItems(['Dummy', 'LMScreen', 'Vimba'])
-        self._ui.cmb_motor_type.addItems(['None', 'FSBT', 'Acromag'])
+        self._ui.cmd_rescan_database.clicked.connect(self._rescan_database)
+
+        self._ui.chk_manual_tango_device.stateChanged.connect(self._manual_tango_device)
 
         if settings_node is not None:
             self._ui.le_name.setText(settings_node.get('name'))
@@ -39,19 +51,26 @@ class CameraSettings(QtWidgets.QWidget):
                 self._ui.chk_enabled.setChecked(True)
 
             camera_type = settings_node.get('proxy')
-            if camera_type == 'DummyProxy':
-                refresh_combo_box(self._ui.cmb_camera_type, 'Dummy')
-            elif camera_type == 'TangoTineProxy':
-                refresh_combo_box(self._ui.cmb_camera_type, 'LMScreen')
+            refresh_combo_box(self._ui.cmb_camera_type, camera_type)
+
+            if camera_type in ['LMScreen', 'TangoVimba']:
                 self._ui.fr_tango.setVisible(True)
-            elif camera_type == 'VimbaProxy':
-                refresh_combo_box(self._ui.cmb_camera_type, 'Vimba')
-                self._ui.fr_tango.setVisible(True)
-            else:
-                raise RuntimeError('Unknown type')
+
+            if camera_type == 'TangoVimba':
+                self._ui.fr_vimba_picture_setings.setVisible(True)
 
             if 'tango_server' in settings_node.keys():
-                self._ui.le_tango_server.setText(settings_node.get('tango_server'))
+                server = settings_node.get('tango_server')
+                try:
+                    self._ui.le_tango_host.setText(PyTango.DeviceProxy(server).get_db_host().split('.')[0])
+                    self._rescan_database()
+                    set_manual = not refresh_combo_box(self._ui.cmb_tango_device, PyTango.DeviceProxy(server).dev_name())
+                except:
+                    set_manual = True
+
+                if set_manual:
+                    self._ui.chk_manual_tango_device.setChecked(True)
+                    self._ui.le_tango_server.setText(server)
             if 'settings_server' in settings_node.keys():
                 self._ui.le_settings_server.setText(settings_node.get('settings_server'))
             if 'roi_server' in settings_node.keys():
@@ -78,17 +97,34 @@ class CameraSettings(QtWidgets.QWidget):
                 self._ui.chk_flip_h.setChecked(strtobool(settings_node.get('flip_horizontal')))
             if 'rotate' in settings_node.keys():
                 self._ui.sp_rotate.setValue(int(settings_node.get('rotate')))
+            if 'high_depth' in settings_node.keys():
+                self._ui.chk_high_depth.setChecked(strtobool(settings_node.get('high_depth')))
+            if 'color' in settings_node.keys():
+                self._ui.chk_color.setChecked(strtobool(settings_node.get('color')))
 
             pass
 
+    # ----------------------------------------------------------------------
+    def _rescan_database(self):
+        current_selection = self._ui.cmb_tango_device.currentText()
+        self._ui.cmb_tango_device.clear()
+        self._ui.cmb_tango_device.addItems(hu.getDeviceNamesByClass(self._ui.cmb_camera_type.currentText(),
+                                                                    self._ui.le_tango_host.text()))
+        refresh_combo_box(self._ui.cmb_tango_device, current_selection)
+
+    # ----------------------------------------------------------------------
+    def _manual_tango_device(self, state):
+        self._ui.le_tango_host.setEnabled(state != 2)
+        self._ui.cmb_tango_device.setEnabled(state != 2)
+        self._ui.cmd_rescan_database.setEnabled(state != 2)
+        self._ui.le_tango_server.setEnabled(state == 2)
+
     # ----------------------------------------------------------------------
     def _switch_camera_type(self, mode):
         self._ui.fr_tango.setVisible(False)
         self._ui.fr_roi.setVisible(False)
         self._ui.fr_settings.setVisible(False)
-        if mode == 'LMScreen':
-            self._ui.fr_tango.setVisible(True)
-        elif mode == 'Vimba':
+        if mode in ['LMScreen', 'TangoVimba']:
             self._ui.fr_tango.setVisible(True)
 
     # ----------------------------------------------------------------------
@@ -104,16 +140,8 @@ class CameraSettings(QtWidgets.QWidget):
     # ----------------------------------------------------------------------
     def get_data(self):
         data_to_save = [('name', self._ui.le_name.text()),
-                        ('enabled', str(self._ui.chk_enabled.isChecked()))]
-
-        if self._ui.cmb_camera_type.currentText() == 'LMScreen':
-            type = 'TangoTineProxy'
-        elif self._ui.cmb_camera_type.currentText() == 'Vimba':
-            type = 'VimbaProxy'
-        else:
-            type = 'DummyProxy'
-
-        data_to_save.append(('proxy', type))
+                        ('enabled', str(self._ui.chk_enabled.isChecked())),
+                        ('proxy', self._ui.cmb_camera_type.currentText())]
 
         if self._ui.cmb_motor_type.currentText() == 'FSBT':
             data_to_save.append(('motor_type', 'FSBT'))
@@ -128,14 +156,20 @@ class CameraSettings(QtWidgets.QWidget):
         else:
             data_to_save.append((('motor_type', 'none')),)
 
-        if type == 'TangoTineProxy':
-            data_to_save.append(('tango_server', self._ui.le_tango_server.text()))
-        elif type == 'VimbaProxy':
-            data_to_save.append(('tango_server', self._ui.le_tango_server.text()))
+        if self._ui.cmb_camera_type.currentText() in ['LMScreen', 'TangoVimba']:
+            if self._ui.chk_manual_tango_device.isChecked():
+                address = self._ui.le_tango_server.text()
+            else:
+                address = self._ui.le_tango_host.text() + ':10000/' + self._ui.cmb_tango_device.currentText()
+
+            data_to_save.append(('tango_server', address))
 
         data_to_save.append(('flip_vertical', str(self._ui.chk_flip_v.isChecked())))
         data_to_save.append(('flip_horizontal', str(self._ui.chk_flip_h.isChecked())))
         data_to_save.append(('rotate', str(self._ui.sp_rotate.value())))
+        if self._ui.cmb_camera_type.currentText() == 'TangoVimba':
+            data_to_save.append(('high_depth', str(self._ui.chk_high_depth.isChecked())))
+            data_to_save.append(('color', str(self._ui.chk_color.value())))
 
         return data_to_save
 
